#!/usr/bin/env python
"""
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

"""

import sys

from resource_management.core.exceptions import ComponentIsNotRunning
from resource_management.libraries.functions.check_process_status import check_process_status
from resource_management.libraries.script import Script
from resource_management.libraries.functions import format

if sys.version_info[0] == 2:
    reload(sys)
    sys.setdefaultencoding('utf8')

config = Script.get_config()

RESULT_CODE_OK = 'OK'
RESULT_CODE_CRITICAL = 'CRITICAL'
RESULT_CODE_UNKNOWN = 'UNKNOWN'
registry_pid_dir = config['configurations']['registry-env']['registry_pid_dir']


def execute(configurations={}, parameters={}, host_name=None):
    try:
        registry_pid_file = registry_pid_dir + '/registry.pid'
        check_process_status(registry_pid_file)
    except ComponentIsNotRunning as ex:
        return (RESULT_CODE_CRITICAL, [str(ex)])
    except:
        return (RESULT_CODE_CRITICAL, ["Schema Registry is not running"])

    return (RESULT_CODE_OK, ["Schema Registry process is up and running"])

